@@ -5,6 +5,8 @@ from django.views.generic import TemplateView, CreateView, FormView
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 
+from feedback_form import forms
+
 class CompletedPage(TemplateView):
     template_name = "feedback_form/feedback_done.html"
 
@@ -27,4 +29,4 @@ class ContactFormMixin(object):
 	
 class ContactFormView(ContactFormMixin, FormView):
   template_name="feedback_form/feedback.html"
-  form_class=forms.ContactForm,
+  form_class=forms.ContactForm
